#' @importFrom magrittr %>%
#' @export
magrittr::`%>%`
#' @importFrom tibble tibble
#' @export
tibble::tibble
#' @importFrom dplyr mutate
#' @export
dplyr::mutate
#' @importFrom dplyr filter
#' @export
dplyr::filter
#' @importFrom dplyr group_by
#' @export
dplyr::group_by
#' @importFrom dplyr select
#' @export
dplyr::select
#' @importFrom tidyr drop_na
#' @export
tidyr::drop_na
#' @importFrom tidyr gather
#' @export
tidyr::gather
#' @importFrom tidyr spread
#' @export
tidyr::spread
#' @importFrom broom tidy
#' @export
broom::tidy
#' @importFrom broom augment
#' @export
broom::augment
#' @importFrom car Anova
#' @export
car::Anova
#' @importFrom car Manova
#' @export
car::Manova
